@@ -129,6 +129,8 @@ void MainWindow::on_searchButton_clicked()
         message->show();
         network->searchKeyWord(this->ui->searchLineEdit->text());
         this->searchWord = this->ui->searchLineEdit->text();
+        this->ui->label->hide();
+        this->ui->label_2->hide();
     }
 }
 
