@@ -46,7 +46,7 @@ void Playlist::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
 
 }
 
-void Playlist::on_treeWidget_itemPressed(QTreeWidgetItem *item, int column)
+void Playlist::on_treeWidget_itemDoubleClicked(QTreeWidgetItem *item, int column)
 {
     if (item->childCount() == 0)
         playlistlist->removePlaylistItem(item->data(1, 1).toString(), column, item->parent());
